# -*- coding: utf-8 -*-
##############################################################################
#
# ScoDoc
#
# Copyright (c) 1999 - 2021 Emmanuel Viennet.  All rights reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#   Emmanuel Viennet      emmanuel.viennet@viennet.net
#
##############################################################################

from flask import flash, redirect, url_for, render_template
from werkzeug.utils import secure_filename

import app.scodoc.sco_utils as scu
import app
from app import Departement, ScoValueError
from app.models import ScoDocSiteConfig
from app.scodoc import sco_logos
import flask
from flask import jsonify, url_for, flash, redirect, render_template, make_response
from wtforms import SelectField, FileField, FormField, HiddenField
from flask import current_app, g, request
from flask_login import current_user
from flask_wtf import FlaskForm
from wtforms import SubmitField
from flask_wtf.file import FileField, FileAllowed


# ---- CONFIGURATION
from app.scodoc.sco_logos import list_logos


class SimpleForm(FlaskForm):
    key = HiddenField("form_id")
    logo = FileField(
        label="Modifier l'image:",
        description="logo",
        validators=[
            FileAllowed(
                scu.LOGOS_IMAGES_ALLOWED_TYPES,
                f"n'accepte que les fichiers image <tt>{','.join([e for e in scu.LOGOS_IMAGES_ALLOWED_TYPES])}</tt>",
            )
        ],
    )
    submit = SubmitField("submit")

    # def __init__(self, **kwargs):
    #     super().__init__(**kwargs)


class LogoForm(FlaskForm):
    header = FormField(SimpleForm, label="header")
    footer = FormField(SimpleForm, label="footer")

    logo = FileField(
        label="Modifier l'image:",
        description="logo",
        validators=[
            FileAllowed(
                scu.LOGOS_IMAGES_ALLOWED_TYPES,
                f"n'accepte que les fichiers image <tt>{','.join([e for e in scu.LOGOS_IMAGES_ALLOWED_TYPES])}</tt>",
            )
        ],
    )


class ScoDocConfigurationForm(FlaskForm):
    """Panneau de configuration général"""

    bonus_sport_func_name = SelectField(
        label="Fonction de calcul des bonus sport&culture",
        choices=[
            (x, x if x else "Aucune")
            for x in ScoDocSiteConfig.get_bonus_sport_func_names()
        ],
    )

    # logo_header = FileField(
    #     label="Modifier l'image:",
    #     description="logo placé en haut des documents PDF",
    #     validators=[
    #         FileAllowed(
    #             scu.LOGOS_IMAGES_ALLOWED_TYPES,
    #             f"n'accepte que les fichiers image <tt>{','.join([e for e in scu.LOGOS_IMAGES_ALLOWED_TYPES])}</tt>",
    #         )
    #     ],
    # )

    # logo_footer = FileField(
    #     label="Modifier l'image:",
    #     description="logo placé en pied des documents PDF",
    #     validators=[
    #         FileAllowed(
    #             scu.LOGOS_IMAGES_ALLOWED_TYPES,
    #             f"n'accepte que les fichiers image <tt>{','.join([e for e in scu.LOGOS_IMAGES_ALLOWED_TYPES])}</tt>",
    #         )
    #     ],
    # )

    submit = SubmitField("Enregistrer")


def configuration():
    """Panneau de configuration général"""
    inventory = list_logos()
    form = LogoForm()
    # form = ScoDocConfigurationForm(
    #     bonus_sport_func_name=ScoDocSiteConfig.get_bonus_sport_func_name(),
    # )
    if form.validate_on_submit():
        # ScoDocSiteConfig.set_bonus_sport_func(form.bonus_sport_func_name.data)
        # if form.logo_header.data:
        #     sco_logos.store_image(
        #         form.logo_header.data, os.path.join(scu.SCODOC_LOGOS_DIR, "logo_header")
        #     )
        # if form.logo_footer.data:
        #     sco_logos.store_image(
        #         form.logo_footer.data, os.path.join(scu.SCODOC_LOGOS_DIR, "logo_footer")
        #     )
        # app.clear_scodoc_cache()
        # flash(f"Configuration enregistrée")
        return redirect(url_for("scodoc.index"))
    return render_template(
        "configuration.html",
        title="Configuration ScoDoc",
        form=form,
        scodoc_dept=None,
        inventory=inventory,
    )
